require 'sketchup'

dir = File.dirname(__FILE__)
ops = (RUBY_PLATFORM =~ /mswin|mingw/i) ? 'win' : 'mac'
bit = (Sketchup.respond_to?('is_64bit?') && Sketchup.is_64bit? )? '64' : '32'
ver = (RUBY_VERSION =~ /1.8/) ? '1.8' : '2.0'

require File.join(dir, ops+bit, ver, 'dacastror')

module Dacastror
  class MyWindowsObserver

    public

    def initialize
    end

    # For convenience, we're going to make observer callback methods private.
    private

    def on_enter_size_move
      puts "Main window started transforming."
    end

    def on_exit_size_move
      puts "Main window finished transforming."
    end

    def on_size
     puts "Main window sized."
    end

    def on_move
      puts "Main window moved."
    end

    def on_viewport_resize
      puts "Viewport resized."
    end
  end # class MyWindowsObserver
end # module Dacastror

unless file_loaded?(__FILE__)
  file_loaded(__FILE__)

  # Availbable functions are:
  #  Dacastror::Windows.get_main_handle
  #  Dacastror::Windows.get_viewport_handle
  #  Dacastror::Windows.get_viewport_rect
  #  Dacastror::Windows.add_observer(object)
  #  Dacastror::Windows.remove_observer(object)
  # Available observer methods are:
  #  on_enter_size_move - called when main window starts transforming.
  #  on_exit_size_move - called when main window is done transforming.
  #  on_size - called when main window is sizing
  #  on_move - called when main window is moving
  #  on_viewport_resize - called when viewport window is resized. This happens
  #    when main window is sized or when docked toolbars are rearranged, forcing
  #    viewport to resize.

  # For your webdialog project, I would use on_move and on_viewport_size.
  # I think the rest aren't necessary. And, FYI, you don't have to include all
  # callback mehods in your tool. Use only those that are necessary.

  # Add our observer
  my_observer = Dacastror::MyWindowsObserver.new
  Dacastror::Windows.add_observer(my_observer)

  # Remove our observer
  #~ Dacastror::Windows.remove_observer(my_observer)

  # Display Ruby Console
  show_ruby_panel
  # Wait till console is ready and then output some info.
  UI.start_timer(0.5, false) {
    puts "Move and size SU main window to see Dacastror Windows observer respond!"
  }
end
